@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: blt2d.tcl,v 1.25 1998/10/10 20:58:19 jfontain Exp $}
+set rcsId {$Id: blt2d.tcl,v 1.28 1998/11/15 10:48:55 jfontain Exp $}
 
 class blt2DViewer {
 
@@ -28,9 +28,13 @@ if {$::officialBLT} {
     }
 
     proc ~blt2DViewer {this} {
-        catch {delete $blt2DViewer::($this,drag)}
+        if {[info exists blt2DViewer::($this,drag)]} {
+            delete $blt2DViewer::($this,drag)
+        }
         delete $blt2DViewer::($this,drop)
-        catch {delete $blt2DViewer::($this,selector)}
+        if {[info exists blt2DViewer::($this,selector)]} {
+            delete $blt2DViewer::($this,selector)
+        }
         eval delete $blt2DViewer::($this,elements)                                                       ;# delete existing elements
     }
 
@@ -70,15 +74,18 @@ if {$::officialBLT} {
         viewer::registerTrace $this $array
         set cell ${array}($row,$column)
         if {[lsearch -exact [cellsFromElements $this $blt2DViewer::($this,elements)] $cell]>=0} return     ;# already charted, abort
-        set element [newElement $this $blt2DViewer::($this,path) -label [viewer::label $array $row $column]]
-        switched::configure $element -color [lindex $blt2DViewer::(colors) $blt2DViewer::($this,colorIndex)]
+        set element [newElement $this $blt2DViewer::($this,path)\
+            -label [viewer::label $array $row $column] -color [lindex $blt2DViewer::(colors) $blt2DViewer::($this,colorIndex)]\
+        ]
         # keep track of element existence
         switched::configure $element -deletecommand "blt2DViewer::deletedElement $this $array $element"
         # circle through colors
         set blt2DViewer::($this,colorIndex) [expr {($blt2DViewer::($this,colorIndex)+1)%[llength $blt2DViewer::(colors)]}]
         lappend blt2DViewer::($this,elements) $element                                                     ;# register new data line
         set blt2DViewer::($this,cell,$element) $cell
-        catch {selector::add $blt2DViewer::($this,selector) $element}               ;# selector may not exist if dragging disallowed
+        if {[info exists blt2DViewer::($this,selector)]} {                          ;# selector may not exist if dragging disallowed
+            selector::add $blt2DViewer::($this,selector) $element
+        }
     }
 
     proc cells {this} {
@@ -88,7 +95,9 @@ if {$::officialBLT} {
     proc deletedElement {this array element} {
         viewer::unregisterTrace $this $array                                          ;# trace may no longer be needed on this array
         ldelete blt2DViewer::($this,elements) $element
-        catch {selector::remove $blt2DViewer::($this,selector) $element}            ;# selector may not exist if dragging disallowed
+        if {[info exists blt2DViewer::($this,selector)]} {                          ;# selector may not exist if dragging disallowed
+            selector::remove $blt2DViewer::($this,selector) $element
+        }
         unset blt2DViewer::($this,cell,$element)
         if {[llength $blt2DViewer::($this,elements)]==0} {
             delete $this                                                            ;# self destruct when there are no more elements
@@ -100,9 +109,11 @@ if {$::officialBLT} {
         foreach element $blt2DViewer::($this,elements) {
             set cell $blt2DViewer::($this,cell,$element)
             if {[string first $array $cell]<0} continue                                  ;# check that cell belongs to updated array
-            set value {}                                                        ;# set default to void in case data no longer exists
-            catch {set value [set $cell]}
-            updateElement $this $element $seconds $value
+            if {[info exists $cell]} {
+                updateElement $this $element $seconds [set $cell]
+            } else {
+                updateElement $this $element $seconds {}                                                    ;# data no longer exists
+            }
         }
     }
 
