@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: canvhand.tcl,v 1.18 1998/07/11 09:56:54 jfontain Exp $}
+set rcsId {$Id: canvhand.tcl,v 1.20 1998/11/08 21:39:33 jfontain Exp $}
 
 class canvasWindowManager {
 
@@ -18,7 +18,9 @@ class canvasWindowManager {
 
         proc ~handles {this} {
             [set ($this,canvas)] delete [set ($this,item)] outline                       ;# delete canvas items (eventually outline)
-            catch {delete [set ($this,bindings)]}                                                      ;# eventually delete bindings
+            if {[info exists ($this,bindings)]} {                                                      ;# eventually delete bindings
+                delete [set ($this,bindings)]
+            }
         }
 
         proc options {this} {
@@ -49,7 +51,9 @@ class canvasWindowManager {
             }
             set path $widget::($this,path)
             catch {eval pack forget [pack slaves $path]}                                        ;# eventually forget existing widget
-            catch {delete [set ($this,bindings)]}                                             ;# eventually delete existing bindings
+            if {[info exists ($this,bindings)]} {                                                      ;# eventually delete bindings
+                delete [set ($this,bindings)]
+            }
             set ($this,bindings) [new bindings $value end]
             bindings::set [set ($this,bindings)] <Visibility>\
                 "set canvasWindowManager::handles::($this,partiallyObscured) \[string compare %s VisibilityUnobscured\]"
@@ -116,7 +120,9 @@ class canvasWindowManager {
             } else {
                 lower $widget::($this,path)                     ;# else place below other windows so they get a chance to be visible
             }
-            catch {raise $composite::($this,-path) $widget::($this,path)} ;# maintain managed widget (if it exists) just above frame
+            if {[string length $composite::($this,-path)]>0} {                                           ;# if managed widget exists
+                raise $composite::($this,-path) $widget::($this,path)                                ;# maintain it just above frame
+            }
         }
 
         proc buttonRelease {this} {
@@ -124,8 +130,9 @@ class canvasWindowManager {
             if {[info exists (motion)]} {                                                              ;# moving or resizing occured
                 updateGeometry $this
                 raise $widget::($this,path)                                          ;# always place frame on top after acting on it
-                # maintain managed widget (if it exists) just above frame
-                catch {raise $composite::($this,-path) $widget::($this,path)}
+                if {[string length $composite::($this,-path)]>0} {                                       ;# if managed widget exists
+                    raise $composite::($this,-path) $widget::($this,path)                            ;# maintain it just above frame
+                }
                 unset (motion)
             } else {                                                                                ;# no moving or resizing occured
                 toggleVisibility $this
@@ -286,7 +293,7 @@ class canvasWindowManager {
             # create outline borders (a single frame with no background cannot be used for it hides underlying windows)
             set canvas [set ($this,canvas)]
             foreach side {top bottom left right} {
-                set frame $widget::([new frame $canvas -background black],path)                         ;# make sure frame is unique
+                set frame [frame $canvas.${side}outline -background black]
                 # items are static because there can be only 1 outline at a time
                 set ($side,item) [$canvas create window 0 0 -window $frame -width 0 -height 0 -anchor nw -tags outline]
             }
