@@ -1,10 +1,12 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: config.tcl,v 1.3 1998/05/24 19:24:43 jfontain Exp $}
+set rcsId {$Id: config.tcl,v 1.4 1998/11/08 20:40:42 jfontain Exp $}
 
 class configuration {
     set (xWindowManagerInitialOffset) 30
     set (yWindowManagerInitialOffset) 20
     set (graphNumberOfIntervals) 100
+    set (default,viewer,height) 200
+    set (default,viewer,width) 300
 }
