@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: databar.tcl,v 1.15 1998/10/11 09:27:20 jfontain Exp $}
+set rcsId {$Id: databar.tcl,v 1.16 1998/11/08 20:49:41 jfontain Exp $}
 
 class dataBarChart {
 
@@ -31,9 +31,9 @@ if {$::officialBLT} {
         return [list\
             [list -deletecommand {} {}]\
             [list -draggable draggable Draggable 0 0]\
-            [list -height height Height 200]\
+            [list -height height Height $configuration::(default,viewer,height)]\
             [list -mode mode Mode normal normal]\
-            [list -width width Width 300]\
+            [list -width width Width $configuration::(default,viewer,width)]\
         ]
     }
 
