@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datagraf.tcl,v 1.44 1998/10/11 09:27:20 jfontain Exp $}
+set rcsId {$Id: datagraf.tcl,v 1.45 1998/11/15 11:09:07 jfontain Exp $}
 
 
 class dataGraph {
@@ -55,10 +55,10 @@ if {$::officialBLT} {
         return [list\
             [list -deletecommand {} {}]\
             [list -draggable draggable Draggable 0 0]\
-            [list -height height Height 200]\
+            [list -height height Height $configuration::(default,viewer,height)]\
             [list -interval interval Interval 5]\
             [list -samples samples Samples $samples $samples]\
-            [list -width width Width 300]\
+            [list -width width Width $configuration::(default,viewer,width)]\
         ]
     }
 
@@ -103,7 +103,7 @@ if {$::officialBLT} {
     }
 
     proc newElement {this path args} {                                                          ;# invoked from 2D viewer base class
-        return [eval new element $path $args]
+        return [eval new element $path $composite::($this,-interval) $args]
     }
 
     proc updateTimeDisplay {this seconds} {
@@ -143,37 +143,35 @@ class dataGraph {
 
     class element {
 
-        set (vectorIndex) 0                                               ;### remove with official BLT when #auto feature works ###
-
-        proc element {this path args} switched {$args} {
-            global [set ($this,xVector) vector[incr (vectorIndex)]] [set ($this,yVector) vector[incr (vectorIndex)]]
-
-            $path element create $this -label {} -symbol none                         ;# use object identifier as element identifier
+        proc element {this path interval args} switched {$args} {                ;# interval is required to properly draw fist point
             set dots [expr {$configuration::(graphNumberOfIntervals)+1}]
 if {$::officialBLT} {
-            ### blt::vector create #auto($dots) should ultimately work ###
-            global [set ($this,weights) vector[incr (vectorIndex)]]    ;### necessary? namespace variable automatically created? ###
-            blt::vector create [set ($this,xVector)]($dots)                                                    ;# x axis data vector
-            blt::vector create [set ($this,yVector)]($dots)                                                    ;# y axis data vector
-            blt::vector create [set ($this,weights)]($dots)                                                   ;# weights data vector
-            $path element configure $this -weight [set ($this,weights)] -styles {{void 0 0}}                   ;# handle void values
+            # prevent BLT core dumps by working at the global level instead of the namespace level
+            uplevel #0 "
+                blt::vector create xVector${this}($dots)                                                       ;# x axis data vector
+                blt::vector create yVector${this}($dots)                                                       ;# y axis data vector
+                blt::vector create weightVector${this}($dots)                                                 ;# weights data vector
+                # use object identifier as element identifier
+                $path element create $this -label {} -symbol none -xdata xVector$this -ydata yVector$this\
+                    -weight weightVector$this -styles {{void 0 0}}                                             ;# handle void values
+            "
 } else {
-            blt::vector [set ($this,xVector)]($dots)
-            blt::vector [set ($this,yVector)]($dots)
+            uplevel #0 "
+                blt::vector xVector${this}($dots)
+                blt::vector yVector${this}($dots)
+                $path element create $this -label {} -symbol none -xdata xVector$this -ydata yVector$this
+            "
 }
-            $path element configure $this -xdata [set ($this,xVector)] -ydata [set ($this,yVector)]
             set ($this,path) $path
+            set ($this,interval) $interval
             switched::complete $this
         }
 
         proc ~element {this} {
-            global [set ($this,xVector)] [set ($this,yVector)]
-
 if {$::officialBLT} {
-            global [set ($this,weights)]
-            blt::vector destroy [set ($this,xVector)] [set ($this,yVector)] [set ($this,weights)]
+            uplevel #0 blt::vector destroy xVector$this yVector$this weightVector$this
 } else {
-            unset [set ($this,xVector)] [set ($this,yVector)]
+            uplevel #0 unset xVector$this yVector$this
 }
             [set ($this,path)] element delete $this
             if {[string length $switched::($this,-deletecommand)]>0} {
@@ -198,24 +196,32 @@ if {$::officialBLT} {
 if {$::officialBLT} {
 
         proc update {this x y} {
-            global [set ($this,xVector)] [set ($this,yVector)] [set ($this,weights)]
-
-            if {[set [set ($this,xVector)](end)]==0} {                                                               ;# first update
+            if {[uplevel #0 set xVector${this}(end)]==0} {                                                           ;# first update
                 if {[string length $y]==0} return                                            ;# do nothing till we get a valid value
-                set [set ($this,xVector)](end) $x                                 ;# make 2 last points identical so a dot is traced
-                set [set ($this,yVector)](end) $y
+                # make an horizontal line as short as possible so that first point is visible
+                uplevel #0 "
+                    set xVector${this}(end) [expr {$x-[set ($this,interval)]}]
+                    set yVector${this}(end) $y
+                "
+                unset ($this,interval)                                                                           ;# free some memory
             }
-            [set ($this,xVector)] delete 0                                            ;# achieve scrolling by deleting first element
-            [set ($this,yVector)] delete 0
-            [set ($this,weights)] delete 0
-            [set ($this,xVector)] append $x                                                               ;# and appending new value
+            uplevel #0 "
+                xVector$this delete 0                                                 ;# achieve scrolling by deleting first element
+                yVector$this delete 0
+                weightVector$this delete 0
+                xVector$this append $x                                                                    ;# and appending new value
+            "
             if {[string length $y]==0} {                                                                           ;# void new value
-                [set ($this,yVector)] append [set [set ($this,yVector)](end)]                             ;# append last known value
-                [set ($this,weights)] append 0                                                        ;# and display with void style
+                uplevel #0 "
+                    yVector$this append \[set yVector${this}(end)\]                                       ;# append last known value
+                    weightVector$this append 0                                                        ;# and display with void style
+                "
                 [set ($this,path)] element configure $this -label "$switched::($this,-label): ?"
-            } else {                                                                                              ;# valid new valid
-                [set ($this,yVector)] append $y
-                [set ($this,weights)] append 1                                                                       ;# normal style
+            } else {                                                                                              ;# valid new value
+                uplevel #0 "
+                    yVector$this append $y
+                    weightVector$this append 1                                                                       ;# normal style
+                "
                 [set ($this,path)] element configure $this -label "$switched::($this,-label): $y"
             }
         }
@@ -223,22 +229,24 @@ if {$::officialBLT} {
 } else {
 
         proc update {this x y} {
-            global [set ($this,xVector)] [set ($this,yVector)]
-
             if {[string length $y]==0} {                                                                           ;# void new value
                 set y 0                                                                                   ;# cannot handle void type
                 [set ($this,path)] element configure $this -label "$switched::($this,-label): ?"
             } else {
                 [set ($this,path)] element configure $this -label "$switched::($this,-label): $y"
             }
-            if {[set [set ($this,xVector)](end)]==0} {                                                               ;# first update
-                set [set ($this,xVector)](:) $x          ;# make all points identical so curve seems to start from first valid value
-                set [set ($this,yVector)](:) $y
+            if {[uplevel #0 set xVector${this}(end)]==0} {                                                           ;# first update
+                uplevel #0 "
+                    set xVector${this}(:) $x             ;# make all points identical so curve seems to start from first valid value
+                    set yVector${this}(:) $y
+                "
             }
-            [set ($this,xVector)] delete 0                                            ;# achieve scrolling by deleting first element
-            [set ($this,yVector)] delete 0
-            [set ($this,xVector)] append $x                                                               ;# and appending new value
-            [set ($this,yVector)] append $y
+            uplevel #0 "
+                xVector$this delete 0                                                 ;# achieve scrolling by deleting first element
+                yVector$this delete 0
+                xVector$this append $x                                                                    ;# and appending new value
+                yVector$this append $y
+            "
         }
 
 }
