@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datapie.tcl,v 1.26 1998/10/11 09:27:20 jfontain Exp $}
+set rcsId {$Id: datapie.tcl,v 1.28 1998/11/08 21:52:58 jfontain Exp $}
 
 class dataPieChart {
 
@@ -32,7 +32,9 @@ class dataPieChart {
 
     proc ~dataPieChart {this} {
         delete $dataPieChart::($this,pie) $dataPieChart::($this,drop)
-        catch {delete $dataPieChart::($this,drag)}
+        if {[info exists dataPieChart::($this,drag)]} {
+            delete $dataPieChart::($this,drag)
+        }
         if {[string length $composite::($this,-deletecommand)]>0} {
             uplevel #0 $composite::($this,-deletecommand)                                   ;# always invoke command at global level
         }
@@ -199,7 +201,9 @@ class dataPieChart {
 
 class data2DPieChart {
 
-    proc data2DPieChart {this parentPath args} dataPieChart {$parentPath 0 -width 200 -height 220 $args} {}
+    proc data2DPieChart {this parentPath args} dataPieChart {
+        $parentPath 0 -width $configuration::(default,viewer,width) -height $configuration::(default,viewer,height) $args
+    } {}
 
     proc ~data2DPieChart {this} {}
 
@@ -221,7 +225,9 @@ class data2DPieChart {
 
 class data3DPieChart {
 
-    proc data3DPieChart {this parentPath args} dataPieChart {$parentPath 20 -width 250 -height 180 $args} {}
+    proc data3DPieChart {this parentPath args} dataPieChart {
+        $parentPath 20 -width $configuration::(default,viewer,width) -height $configuration::(default,viewer,height) $args
+    } {}
 
     proc ~data3DPieChart {this} {}
 
