@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datatab.tcl,v 1.45 1998/10/10 20:56:43 jfontain Exp $}
+set rcsId {$Id: datatab.tcl,v 1.50 1998/11/14 22:21:55 jfontain Exp $}
 
 class dataTable {                       ;# module data view in the form of a table, that can be sorted using a column as a reference
 
@@ -13,6 +13,7 @@ class dataTable {                       ;# module data view in the form of a tab
     proc dataTable {this parentPath args} composite {
         [new scroll table $parentPath\
             -scrollbarwidth $dataTable::(scrollbarWidth) -scrollbarelementborderwidth $dataTable::(scrollbarBorderWidth)\
+            -width $configuration::(default,viewer,width) -height $configuration::(default,viewer,height)\
         ]
         $args
     } {
@@ -43,16 +44,25 @@ class dataTable {                       ;# module data view in the form of a tab
     proc ~dataTable {this} {
         variable ${this}data
 
+        if {[string length $composite::($this,-data)]>0} {
+            setTrace $this 0                                                                                         ;# remove trace
+        }
         catch {unset ${this}data}                                                                      ;# eventually free table data
-        catch {eval delete $dataTable::($this,arrow) $dataTable::($this,tips)}
-        catch {delete $dataTable::($this,drag)}
-        catch {delete $dataTable::($this,selector)}
+        if {[info exists dataTable::($this,arrow)]} {
+            eval delete $dataTable::($this,arrow) $dataTable::($this,tips)
+        }
+        if {[info exists dataTable::($this,drag)]} {
+            delete $dataTable::($this,drag)
+        }
+        if {[info exists dataTable::($this,selector)]} {                            ;# selector may not exist if dragging disallowed
+            delete $dataTable::($this,selector)
+        }
         ldelete dataTable::(list) $this
     }
 
     proc options {this} {
         return [list\
-            [list -columns columns Columns 0 0]\
+            [list -columnwidths columnWidths ColumnWidths {} {}]\
             [list -data data Data {} {}]\
             [list -draggable draggable Draggable 0 0]\
             [list -titlefont titleFont TitleFont $font::(mediumBold) $font::(mediumBold)]\
@@ -60,8 +70,9 @@ class dataTable {                       ;# module data view in the form of a tab
         ]
     }
 
-    proc set-columns {this value} {
-        $dataTable::($this,tablePath) configure -cols $value
+    # list of column widths (as specified in the tkTable manual), applied to existing columns, can be empty.
+    proc set-columnwidths {this value} {
+        updateColumnWidths $this
     }
 
     proc set-titlefont {this value} {
@@ -113,7 +124,9 @@ class dataTable {                       ;# module data view in the form of a tab
             if {$number==0} return
             scan [$dataTable::($this,tablePath) index @$x,$y] %d,%d row column
             if {$row<0} return                                                                           ;# title row, nothing to do
-            catch {selector::select $dataTable::($this,selector) $row,$column}      ;# selector may not exist if dragging disallowed
+            if {[info exists dataTable::($this,selector)]} {
+                selector::select $dataTable::($this,selector) $row,$column
+            }
         }
         unset dataTable::($this,columnBorderHit)
     }
@@ -130,7 +143,9 @@ class dataTable {                       ;# module data view in the form of a tab
             set dataTable::($this,sortOrder) increasing
         }
         # deselect all cells since reordering rows renders selection meaningless
-        catch {selector::clear $dataTable::($this,selector)}                        ;# selector may not exist if dragging disallowed
+        if {[info exists dataTable::($this,selector)]} {
+            selector::clear $dataTable::($this,selector)
+        }
         update $this                                                                                     ;# update table immediately
     }
 
@@ -164,7 +179,9 @@ class dataTable {                       ;# module data view in the form of a tab
         # sort data rows according to sort column (column numbering is identical for table data and source data)
         set lists [lsort -$dataTable::($this,sortOrder) -$data($sortColumn,type) -index 1 $lists]
 
-        catch {set selector $dataTable::($this,selector)}                           ;# selector may not exist if dragging disallowed
+        if {[info exists dataTable::($this,selector)]} {
+            set selector $dataTable::($this,selector)
+        }
         set changed 0                                                        ;# keep track of whether any rows were added or removed
         set row 0
         set rows {}
@@ -193,7 +210,9 @@ class dataTable {                       ;# module data view in the form of a tab
                     lappend cells $new,$column
                 }
             }
-            catch {selector::add $selector $cells}                                       ;# make selector aware of new cells at once
+            if {[info exists selector]} {
+                selector::add $selector $cells                                           ;# make selector aware of new cells at once
+            }
         }
 
         set rows {}
@@ -211,11 +230,13 @@ class dataTable {                       ;# module data view in the form of a tab
                     unset ${this}data($old,$column)
                 }
             }
-            catch {selector::remove $selector $cells}                                ;# make selector aware of removed cells at once
+            if {[info exists selector]} {
+                selector::remove $selector $cells                                    ;# make selector aware of removed cells at once
+            }
         }
 
-        if {$changed} {
-           catch {selector::clear $selector}           ;# deselect all cells since new or deleted rows renders selection meaningless
+        if {$changed&&[info exists selector]} {
+            selector::clear $selector                  ;# deselect all cells since new or deleted rows renders selection meaningless
         }
 
         $path configure -cursor $cursor                                                                            ;# restore cursor
@@ -305,14 +326,14 @@ class dataTable {                       ;# module data view in the form of a tab
             incr column
         }
         $path configure -cols $column                                                              ;# fit table to number of columns
-        if {![info exists dataTable::($this,arrow)]} {                                    ;# use 1 sorting arrow indicator per table
-            set arrow [new arrowButton $path -state disabled -borderwidth 0 -highlightthickness 0 -width 12]
-            widget::configure $arrow -disabledforeground [widget::cget $arrow -foreground]               ;# make arrow fully visible
-            # force default arrow cursor as column resizing cursor sticks when moving across columns
-            $widget::($arrow,path) configure -cursor top_left_arrow
-            lappend dataTable::($this,tips) [new widgetTip -path $widget::($arrow,path) -text {click to toggle sort}]
-            set dataTable::($this,arrow) $arrow
-        }
+        updateColumnWidths $this
+
+        set arrow [new arrowButton $path -state disabled -borderwidth 0 -highlightthickness 0 -width 12]
+        widget::configure $arrow -disabledforeground [widget::cget $arrow -foreground]                   ;# make arrow fully visible
+        # force default arrow cursor as column resizing cursor sticks when moving across columns
+        $widget::($arrow,path) configure -cursor top_left_arrow
+        lappend dataTable::($this,tips) [new widgetTip -path $widget::($arrow,path) -text {click to toggle sort}]
+        set dataTable::($this,arrow) $arrow
     }
 
     proc buttonPress {this x y} {
@@ -353,6 +374,32 @@ class dataTable {                       ;# module data view in the form of a tab
         }
         createTitles $this
         updateSortingArrow $this $sortColumnIndex
-        trace variable $composite::($this,-data)(updates) w "dataTable::update $this"                   ;# track module data updates
+        setTrace $this 1
+    }
+
+    proc updateColumnWidths {this} {                                                        ;# best apply widths to existing columns
+        set path $dataTable::($this,tablePath)
+        set index 0
+        foreach width $composite::($this,-columnwidths) {
+            $path width $index $width
+            if {[incr index]>=[$path cget -cols]} return                                                          ;# no more columns
+        }
+    }
+
+    proc initializationConfiguration {this} {
+        set path $dataTable::($this,tablePath)
+        for {set column 0} {$column<[$path cget -cols]} {incr column} {
+            lappend widths [$path width $column]
+        }
+        return [list -columnwidths $widths]
+    }
+
+    proc setTrace {this on} {
+        if {$on} {
+            set command variable
+        } else {
+            set command vdelete
+        }
+        trace $command $composite::($this,-data)(updates) w "dataTable::update $this"                          ;# track data updates
     }
 }
