@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: drop.tcl,v 1.11 1998/10/09 19:35:44 jfontain Exp $}
+set rcsId {$Id: drop.tcl,v 1.12 1998/11/11 20:24:14 jfontain Exp $}
 
 class dropSite {
     set dropSite::(list) {}                                                                            ;# initialize list of objects
@@ -14,7 +14,9 @@ class dropSite {
     proc ~dropSite {this} {
         set index [lsearch -exact $dropSite::(list) $this]                                                  ;# remove self from list
         set dropSite::(list) [lreplace $dropSite::(list) $index $index]
-        catch {delete $dropSite::($this,bindings)}                                                     ;# eventually remove bindings
+        if {[string length $switched::($this,-path)]>0} {                                        ;# if there was an actual drop site
+            delete $dropSite::($this,bindings)                                                               ;# remove drop bindings
+        }
     }
 
     proc options {this} {
