@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: freetext.tcl,v 1.9 1998/10/18 21:17:53 jfontain Exp $}
+set rcsId {$Id: freetext.tcl,v 1.10 1998/10/25 14:12:30 jfontain Exp $}
 
 class freeText {
 
@@ -17,8 +17,12 @@ class freeText {
 
     proc ~freeText {this} {
         delete $freeText::($this,drop)
-        catch {delete $freeText::($this,drag)}
-        catch {delete $dataTable::($this,selector)}
+        if {[info exists freeText::($this,drag)]} {
+            delete $freeText::($this,drag)
+        }
+        if {[info exists freeText::($this,selector)]} {
+            delete $freeText::($this,selector)
+        }
         eval delete $freeText::($this,labels)
         if {[string length $composite::($this,-deletecommand)]>0} {
             uplevel #0 $composite::($this,-deletecommand)                                   ;# always invoke command at global level
