@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: html.tcl,v 1.15 1998/10/11 09:36:58 jfontain Exp $}
+set rcsId {$Id: html.tcl,v 1.18 1998/11/11 19:55:29 jfontain Exp $}
 
 # use bold and smaller sizes than the HTML library default ones for headers
 array set HMtag_map {
@@ -26,6 +26,12 @@ array set HMinsert_map {
     pre "\n\n" /pre "\n\n"
 }
 
+proc customHMTLConfiguration {path} {                                             ;# make HTML text widget behave more like Netscape
+    $path tag configure mark -foreground black                                                        ;# override list markers color
+    $path tag configure link -borderwidth 1 -foreground blue -underline 1           ;# override hypertext links border and underline
+    set ::HM${path}(S_symbols) oooooo\xd7\xb0>:\xb7                                   ;# use simple circles for list element markers
+}
+
 proc helpWindow {} {
     global htmlHelpDataText
 
@@ -41,10 +47,10 @@ proc helpWindow {} {
     set panes [new panner .topHelp -panes 2]                                         ;# split window in 2 for contents and help data
     pack $widget::($panes,path) -fill both -expand 1
 
-    set contents [new scroll text $panner::($panes,frame1) -horizontal 0 -height 100 -width 400]
+    set contents [new scroll text $panner::($panes,frame1) -horizontal 0 -height 100 -width 500]
     pack $widget::($contents,path) -fill both -expand 1
 
-    set widget [new scroll text $panner::($panes,frame2) -horizontal 0 -height 400]
+    set widget [new scroll text $panner::($panes,frame2) -height 400]
     pack $widget::($widget,path) -fill both -expand 1
 
     bind .topHelp.bound <Destroy> "delete $widget $contents $panes"
@@ -52,7 +58,10 @@ proc helpWindow {} {
     set contentsText $composite::($contents,scrolled,path)                                       ;# first setup and display contents
     $contentsText configure -cursor watch                                                 ;# show that we are busy for user feedback
     update idletasks
+
     HMinit_win $contentsText
+    customHMTLConfiguration $contentsText
+
     $contentsText configure -state normal
     HMparse_html $::htmlHelpContents "HMrender $contentsText"
     $contentsText configure -state disabled
@@ -61,7 +70,10 @@ proc helpWindow {} {
     set htmlHelpDataText $composite::($widget,scrolled,path)                                      ;# now setup and display help text
     $htmlHelpDataText configure -cursor watch                                             ;# show that we are busy for user feedback
     update idletasks
+
     HMinit_win $htmlHelpDataText
+    customHMTLConfiguration $htmlHelpDataText
+
     $htmlHelpDataText configure -state normal
     HMparse_html $::htmlHelpData "HMrender $htmlHelpDataText"
     $htmlHelpDataText configure -state disabled
@@ -73,6 +85,11 @@ proc helpWindow {} {
     update idletasks
 }
 
+unset HMevents(Enter)                                                     ;# prevent links highlighting, try to behave like Netscape
+unset HMevents(Leave)
+unset HMevents(1)
+set HMevents(ButtonRelease-1) {-foreground darkblue}
+
 proc HMlink_callback {widget reference} {                                                          ;# supply link callback procedure
     global htmlHelpDataText
 
@@ -81,5 +98,10 @@ proc HMlink_callback {widget reference} {
 }
 
 proc HMset_image {widget label source} {                                                          ;# supply image handling procedure
-    pack propagate [winfo parent $label] 1                    ;# do not display image, display alternate text in the smallest window
+    if {\
+        [catch {image create photo -file $source} image]&&\
+        [catch {image create photo -file [file join /usr/doc/moodss-$::applicationVersion $source]} image]\
+    } return                                                  ;# local directory and rpm documentation directory searched and failed
+    bind $label <Destroy> "image delete $image"                      ;# setup binding so that image is deleted as label is destroyed
+    HMgot_image $label $image                                                               ;# got the image for the specified label
 }
