@@ -8,9 +8,9 @@ exec wish "$0" "$@"
 source utility.tcl
 startGatheringRCSIds
 
-set rcsId {$Id: moodss.tcl,v 1.108 1998/10/17 20:39:24 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.113 1998/11/15 11:12:40 jfontain Exp $}
 
-set applicationVersion 5.0
+set applicationVersion 5.1
 
 source getopt.tcl
 
@@ -196,7 +196,7 @@ if {[catch {package require Tktable 2}]} {
 if {[catch {package require BLT}]} {                                                         ;# in case BLT package is not installed
     switch $tcl_platform(platform) {
         unix {
-            load ./libBLT.so.2.4f
+            load ./libBLT.so.2.4g
         }
         windows {
             load ./blt80.dll                                                  ;# so far, only unofficial 8.0 is supported on Windows
@@ -289,20 +289,28 @@ proc createMessageWidget {parentPath} {
 }
 
 proc createCellsViewer {class cells draggable static {pollTime {}}} {
-    global canvas windowManager
+    global canvas
 
     set viewer [new $class $canvas -draggable $draggable]
-    set path $widget::($viewer,path)
     if {[string length $pollTime]>0} {
         composite::configure $viewer -interval $pollTime
     }
-    canvasWindowManager::manage $windowManager $path
-    composite::configure $viewer -deletecommand "canvasWindowManager::unmanage $windowManager $path"
-    canvasWindowManager::configure $windowManager $path -static $static
     viewer::view $viewer $cells
+    manageViewer $viewer 1 -static $static
     return $viewer
 }
 
+proc manageViewer {viewer destroyable args} {                         ;# arguments are window manager configuration switched options
+    global windowManager
+
+    set path $widget::($viewer,path)
+    canvasWindowManager::manage $windowManager $path
+    eval canvasWindowManager::configure $windowManager $path $args
+    if {$destroyable} {
+        composite::configure $viewer -deletecommand "canvasWindowManager::unmanage $windowManager $path"
+    }
+}
+
 proc createDragAndDropZone {parentPath} {
     global canvas pollTime static
 
@@ -468,42 +476,34 @@ pack $widget::($scroll,path) -fill both -expand 1
 
 set draggable [expr {!$readOnly}]
 
-set x 0
-set y 0
+set x 0.0
+set y 0.0
 foreach module $modules(all) {
-    upvar #0 ${module}::data data
-    if {[info exists data(views)]} {                                                                   ;# user overrode default view
-        set index 0
-        foreach members $data(views) {                                                    ;# create and manage a table for each view
+    if {[info exists ${module}::data(views)]} {                                                        ;# user overrode default view
+        set viewMembers [set ${module}::data(views)]                                      ;# create and manage a table for each view
+    } else {
+        set viewMembers {{}}                                                           ;# there is a single table (the default view)
+    }
+    set index 0
+    foreach members $viewMembers {
+        if {[llength $members]>0} {                                                                                  ;# it is a view
             array set view $members
             set table [new dataTable $canvas -data ${module}::data -view ::view -draggable $draggable]
-            canvasWindowManager::manage $windowManager $widget::($table,path)
             unset view
-            if {[info exists initializer]} {
-                foreach {x y width height} [record::tableGeometry $initializer $module $index] {}  ;# used stored geometry for table
-                canvasWindowManager::configure $windowManager $widget::($table,path)\
-                    -setx $x -sety $y -setwidth $width -setheight $height
-            } else {
-                canvasWindowManager::configure $windowManager $widget::($table,path) -setx $x -sety $y
-                incr x $configuration::(xWindowManagerInitialOffset)                      ;# offset tables to achieve a nicer layout
-                incr y $configuration::(yWindowManagerInitialOffset)
-            }
-            canvasWindowManager::configure $windowManager $widget::($table,path) -static $static
-            incr index                                                                                  ;# next view for initializer
+        } else {                                                                                     ;# use single default data view
+            set table [new dataTable $canvas -data ${module}::data -draggable $draggable]
         }
-    } else {                                                                                                ;# use default data view
-        set table [new dataTable $canvas -data ${module}::data -draggable $draggable]
-        canvasWindowManager::manage $windowManager $widget::($table,path)
         if {[info exists initializer]} {
-            foreach {x y width height} [record::tableGeometry $initializer $module] {}             ;# used stored geometry for table
-            canvasWindowManager::configure $windowManager $widget::($table,path)\
-                -setx $x -sety $y -setwidth $width -setheight $height
+            eval composite::configure $table [record::tableOptions $initializer $module $index]
+            foreach {x y width height} [record::tableGeometry $initializer $module $index] {}      ;# used stored geometry for table
         } else {
-            canvasWindowManager::configure $windowManager $widget::($table,path) -setx $x -sety $y
-            incr x $configuration::(xWindowManagerInitialOffset)                          ;# offset tables to achieve a nicer layout
-            incr y $configuration::(yWindowManagerInitialOffset)
+            set width {}
+            set height {}
         }
-        canvasWindowManager::configure $windowManager $widget::($table,path) -static $static
+        manageViewer $table 0 -static $static -setx $x -sety $y -setwidth $width -setheight $height
+        set x [expr {$x+$configuration::(xWindowManagerInitialOffset)}]                   ;# offset tables to achieve a nicer layout
+        set y [expr {$y+$configuration::(yWindowManagerInitialOffset)}]
+        incr index                                                                                      ;# next view for initializer
     }
 }
 
@@ -512,9 +512,13 @@ refresh
 if {[info exists initializer]} {                  ;# stored configuration, now that modules data is initialized, create some viewers
     foreach {class cells x y width height switchedOptions} [record::viewersData $initializer] {
         set viewer [eval new $class $canvas $switchedOptions -draggable $draggable]
-        canvasWindowManager::manage $windowManager $widget::($viewer,path)
+        foreach list [composite::configure $viewer] {
+            if {[string compare [lindex $list 0] -interval]==0} {                                 ;# viewer supports interval option
+                composite::configure $viewer -interval $pollTime                                          ;# so use current interval
+                break                                                                                                        ;# done
+            }
+        }
         viewer::view $viewer $cells
-        canvasWindowManager::configure $windowManager $widget::($viewer,path)\
-            -setx $x -sety $y -setwidth $width -setheight $height -static $static
+        manageViewer $viewer 1 -static $static -setx $x -sety $y -setwidth $width -setheight $height
     }
 }
