@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: record.tcl,v 1.8 1998/10/17 20:40:52 jfontain Exp $}
+set rcsId {$Id: record.tcl,v 1.10 1998/11/03 20:23:37 jfontain Exp $}
 
 
 class record {
@@ -41,34 +41,32 @@ class record {
             puts $file "    $module \{"
             puts $file "        arguments {}"                                                              ;### when implemented ###
             puts $file "        tables \{"
-            set index 0
             foreach table $dataTable::(list) {
                 # filter other module tables
                 if {[string compare $module [namespace qualifiers [composite::cget $table -data]]]!=0} continue
                 foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($table,path)] {}
-                puts $file "            $index \{"
+                puts $file "            $table \{"
                 puts $file "                x $x y $y width $width height $height"
+                foreach {switch value} [dataTable::initializationConfiguration $table] {
+                    puts $file "                $switch [list $value]"
+                }
                 puts $file "            \}"
-                incr index
             }
             puts $file "        \}"
             puts $file "    \}"
         }
         puts $file \}
         puts $file "viewers \{"
-        set index 0
         foreach viewer $viewer::(list) {
-            puts $file "    $index \{"
+            puts $file "    $viewer \{"
             puts $file "        class [classof $viewer]"
             foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($viewer,path)] {}
             puts $file "        x $x y $y width $width height $height"
             puts $file "        cells {[viewer::cells $viewer]}"
-            set options [viewer::initializationConfiguration $viewer]
-            if {[llength $options]>0} {
-                puts $file "        $options"
+            foreach {switch value} [viewer::initializationConfiguration $viewer] {
+                puts $file "        $switch [list $value]"
             }
             puts $file "    \}"
-            incr index
         }
         puts $file \}
 
@@ -110,8 +108,9 @@ class record {
 
         array set data [set ${this}data(viewers)]
         set list {}
-        foreach index [lsort -integer [array names data]] {
-            array set viewer $data($index)
+        foreach id [lsort -integer [array names data]] {
+            catch {unset viewer}
+            array set viewer $data($id)
             set options {}                                  ;# gather viewer specific switched options in a switch / value pair list
             foreach name [array names viewer -*] {
                 lappend options $name $viewer($name)
@@ -121,17 +120,30 @@ class record {
         return $list
     }
 
-    proc tableGeometry {this module {index 0}} {
+    proc tableData {this module creationIndex dataName} {              ;# index is module data table creation index, starting with 0
         variable ${this}data
+        upvar $dataName data
 
         array set data [set ${this}data(modules)]
         array set moduleData $data($module)
         unset data
         array set tablesData $moduleData(tables)
         unset moduleData
-        array set data $tablesData($index)
-        unset tablesData
-        return "$data(x) $data(y) $data(width) $data(height)"
+        # use table identifier at the specified index in creation order sorted table indices
+        array set data $tablesData([lindex [lsort -integer [array names tablesData]] $creationIndex])
     }
 
+    proc tableGeometry {this module creationIndex} {
+        tableData $this $module $creationIndex data
+        return [list $data(x) $data(y) $data(width) $data(height)]
+    }
+
+    proc tableOptions {this module creationIndex} {
+        tableData $this $module $creationIndex data
+        set options {}                                       ;# gather table specific switched options in a switch / value pair list
+        foreach name [array names data -*] {
+            lappend options $name $data($name)
+        }
+        return $options
+    }
 }
