@@ -1,14 +1,18 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: sumtable.tcl,v 1.9 1998/10/11 09:27:20 jfontain Exp $}
+set rcsId {$Id: sumtable.tcl,v 1.12 1998/11/14 22:21:08 jfontain Exp $}
 
 class summaryTable {
 
-    proc summaryTable {this parentPath args} composite {[new frame $parentPath] $args} viewer {} {
-        variable ${this}data
+    set summaryTable::(nextDataIndex) 0              ;# used when data array index is not specified as an option when creating table
 
-        array set ${this}data {
+    proc summaryTable {this parentPath args} composite {[new frame $parentPath] $args} viewer {} {
+        composite::complete $this
+
+        variable $summaryTable::($this,dataName)                                     ;# after completion, data array name is defined
+
+        array set $summaryTable::($this,dataName) {
             updates 0
             0,label data 0,type ascii 0,message {data cell description}
             1,label current 1,type real 1,message {current value}
@@ -20,12 +24,10 @@ class summaryTable {
         }
         set summaryTable::($this,nextRow) 0
 
-
-        composite::complete $this
-
         # wait till after completion before creating table since some options are not dynamically settable
         set table [new dataTable $widget::($this,path)\
-            -data summaryTable::${this}data -draggable $composite::($this,-draggable) -titlefont $composite::($this,-titlefont)\
+            -data summaryTable::$summaryTable::($this,dataName) -draggable $composite::($this,-draggable)\
+            -titlefont $composite::($this,-titlefont)\
         ]
         ### hack: drag and drop code should be separated from dataTable which should provide a selected member procedure ###
         # allow dropping of data cells ### use same path as drag path to avoid drops in table from table ###
@@ -41,12 +43,16 @@ class summaryTable {
     }
 
     proc ~summaryTable {this} {
-        variable ${this}data
+        variable [set dataName $summaryTable::($this,dataName)]
         variable ${this}cellRow
 
+        foreach name [array names {} $this,rowLastWish,*] {                        ;# delete remaining last wishes, one for each row
+            delete $summaryTable::($name)                                                               ;# which in turn deletes row
+        }
         delete $summaryTable::($this,dataTable) $summaryTable::($this,drop)
-        unset ${this}data
         catch {unset ${this}cellRow}
+        incr ${dataName}(updates)                                        ;# so related viewers can eventually show disappeared cells
+        unset $dataName
         if {[string length $composite::($this,-deletecommand)]>0} {
             uplevel #0 $composite::($this,-deletecommand)                                   ;# always invoke command at global level
         }
@@ -64,13 +70,31 @@ class summaryTable {
     }
 
     proc options {this} {
+        # data index must be forced so that initialization always occur
         return [list\
+            [list -dataindex {}]\
             [list -deletecommand {} {}]\
             [list -draggable draggable Draggable 0 0]\
             [list -titlefont titleFont TitleFont $font::(mediumBold) $font::(mediumBold)]\
         ]
     }
 
+    # data array name index must be specifiable so that data viewers depending on summary table data array name (through their
+    # monitored cells) do not fail accessing that data (required when generating viewers from save file)
+    proc set-dataindex {this value} {
+        if {$composite::($this,complete)} {
+            error {option -dataindex cannot be set dynamically}
+        }
+        if {[string length $value]>0} {                             ;# specified, else use internally generated next available index
+            if {$value<$summaryTable::(nextDataIndex)} {
+                error "specified data index ($value) is lower than internal summary table index"
+            }
+            set summaryTable::(nextDataIndex) $value
+        }
+        set summaryTable::($this,dataName) $summaryTable::(nextDataIndex)data                ;# generate unique name based on index
+        incr summaryTable::(nextDataIndex)
+    }
+
     proc set-deletecommand {this value} {}
 
     foreach option {-draggable -titlefont} {
@@ -86,7 +110,7 @@ class summaryTable {
     }
 
     proc monitorCell {this array row column} {
-        variable ${this}data
+        variable [set dataName $summaryTable::($this,dataName)]
         variable ${this}cellRow
 
         viewer::registerTrace $this $array
@@ -96,9 +120,9 @@ class summaryTable {
         set label [viewer::label $array $row $column]
 
         set row $summaryTable::($this,nextRow)                                                       ;# next row for this data table
-        set ${this}data($row,0) $label
-        array set ${this}data "$row,2 {} $row,3 {} $row,4 {}"             ;# initialize average, minimum and maximum to empty values
-        set ${this}data($row,sum) 0.0
+        set ${dataName}($row,0) $label
+        array set $dataName [list $row,2 {} $row,3 {} $row,4 {}]          ;# initialize average, minimum and maximum to empty values
+        set ${dataName}($row,sum) 0.0
         set ${this}cellRow($cell) $row                                                                          ;# remember cell row
         # setup action when a row is deleted through a cell drop in trash
         set summaryTable::($this,rowLastWish,$row) [new lastWish "summaryTable::deleteRow $this $cell"]
@@ -106,31 +130,31 @@ class summaryTable {
     }
 
     proc update {this array args} {
-        variable ${this}data
+        variable [set dataName $summaryTable::($this,dataName)]
         variable ${this}cellRow
 
         foreach cell [array names ${this}cellRow] {
             set row [set ${this}cellRow($cell)]
             if {[catch {set $cell} current]} {                                                                ;# cell does not exist
-                set ${this}data($row,1) ?                                 ;# do not touch other columns as their content stays valid
+                set ${dataName}($row,1) ?                                 ;# do not touch other columns as their content stays valid
             } else {
-                set ${this}data($row,1) $current
-                set ${this}data($row,2) [format %.2f\
+                set ${dataName}($row,1) $current
+                set ${dataName}($row,2) [format %.2f\
                     [expr\
-                        {[set ${this}data($row,sum) [expr {[set ${this}data($row,sum)]+$current}]]/([set ${this}data(updates)]+1)}\
+                        {[set ${dataName}($row,sum) [expr {[set ${dataName}($row,sum)]+$current}]]/([set ${dataName}(updates)]+1)}\
                     ]\
                 ]
-                set value [set ${this}data($row,3)]
+                set value [set ${dataName}($row,3)]
                 if {([string length $value]==0)||($current<$value)} {
-                    set ${this}data($row,3) $current
+                    set ${dataName}($row,3) $current
                 }
-                set value [set ${this}data($row,4)]
+                set value [set ${dataName}($row,4)]
                 if {([string length $value]==0)||($current>$value)} {
-                    set ${this}data($row,4) $current
+                    set ${dataName}($row,4) $current
                 }
             }
         }
-        incr ${this}data(updates)                                                                    ;# let data table update itself
+        incr ${dataName}(updates)                                                                    ;# let data table update itself
     }
 
     proc cells {this} {
@@ -157,15 +181,20 @@ class summaryTable {
         }
     }
 
-    proc deleteRow {this cell} {
-        variable ${this}data
+    proc deleteRow {this cell} {                                   ;# last wish object is deleted after completion of this procedure
+        variable [set dataName $summaryTable::($this,dataName)]
         variable ${this}cellRow
 
         set row [set ${this}cellRow($cell)]
-        unset ${this}data($row,0) ${this}data($row,1) ${this}data($row,2) ${this}data($row,3) ${this}data($row,4)\
-            ${this}data($row,sum) summaryTable::($this,rowLastWish,$row)
+        unset ${dataName}($row,0) ${dataName}($row,1) ${dataName}($row,2) ${dataName}($row,3) ${dataName}($row,4)\
+            ${dataName}($row,sum) summaryTable::($this,rowLastWish,$row)
         unset ${this}cellRow($cell)
         dataTable::update $summaryTable::($this,dataTable)
     }
 
+    # data index is needed so that data array that other eventual data viewers depend on is reused when initializing from save file
+    proc initializationConfiguration {this} {
+        scan $summaryTable::($this,dataName) %u index                                       ;# retrieve leading index from data name
+        return [list -dataindex $index]
+    }
 }
